@@ -38,17 +38,20 @@ struct _GeeReadOnlySetIterator {
 	GObject parent_instance;
 	GeeReadOnlySetIteratorPrivate * priv;
 };
+
 struct _GeeReadOnlySetIteratorClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _GeeReadOnlySetPrivate {
 	GeeSet* _set;
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_SET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_SET, GeeReadOnlySetPrivate))
 enum  {
 	GEE_READ_ONLY_SET_DUMMY_PROPERTY,
@@ -69,6 +72,7 @@ struct _GeeReadOnlySetIteratorPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_SET_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorPrivate))
 enum  {
 	GEE_READ_ONLY_SET_ITERATOR_DUMMY_PROPERTY,
@@ -78,6 +82,7 @@ enum  {
 };
 static gboolean gee_read_only_set_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base);
+static GeeReadOnlySetIterator* gee_read_only_set_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static gpointer gee_read_only_set_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_set_iterator_gee_iterator_parent_iface = NULL;
@@ -86,11 +91,11 @@ static gpointer gee_read_only_set_parent_class = NULL;
 static GeeIterableIface* gee_read_only_set_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_set_gee_collection_parent_iface = NULL;
 static GeeSetIface* gee_read_only_set_gee_set_parent_iface = NULL;
-static void gee_read_only_set_dispose (GObject * obj);
+static void gee_read_only_set_finalize (GObject* obj);
 
 
 
-GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set) {
+GeeReadOnlySet* gee_read_only_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set) {
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeReadOnlySet * self;
@@ -109,7 +114,7 @@ GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func,
 	g_value_init (&__params_it->value, G_TYPE_POINTER);
 	g_value_set_pointer (&__params_it->value, g_destroy_func);
 	__params_it++;
-	self = g_object_newv (GEE_TYPE_READ_ONLY_SET, __params_it - __params, __params);
+	self = g_object_newv (object_type, __params_it - __params, __params);
 	gee_read_only_set_set_set (self, set);
 	while (__params_it > __params) {
 		--__params_it;
@@ -120,6 +125,11 @@ GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func,
 }
 
 
+GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set) {
+	return gee_read_only_set_construct (GEE_TYPE_READ_ONLY_SET, g_type, g_dup_func, g_destroy_func, set);
+}
+
+
 static GType gee_read_only_set_real_get_element_type (GeeIterable* base) {
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (base);
@@ -131,7 +141,7 @@ static GeeIterator* gee_read_only_set_real_iterator (GeeIterable* base) {
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (base);
 	if (self->priv->_set == NULL) {
-		return GEE_ITERATOR (gee_read_only_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func));
+		return GEE_ITERATOR (gee_read_only_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
 	}
 	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_set));
 }
@@ -168,8 +178,9 @@ static void gee_read_only_set_real_clear (GeeCollection* base) {
 }
 
 
-static gint gee_read_only_set_real_get_size (GeeReadOnlySet* self) {
-	g_return_val_if_fail (GEE_IS_READ_ONLY_SET (self), 0);
+static gint gee_read_only_set_real_get_size (GeeCollection* base) {
+	GeeReadOnlySet* self;
+	self = GEE_READ_ONLY_SET (base);
 	return gee_collection_get_size (GEE_COLLECTION (self->priv->_set));
 }
 
@@ -181,6 +192,7 @@ void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value) {
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), _tmp1);
+	g_object_notify (((GObject *) (self)), "set");
 }
 
 
@@ -198,7 +210,7 @@ static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base) {
 }
 
 
-static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+static GeeReadOnlySetIterator* gee_read_only_set_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeReadOnlySetIterator * self;
@@ -216,7 +228,7 @@ static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBo
 	g_value_init (&__params_it->value, G_TYPE_POINTER);
 	g_value_set_pointer (&__params_it->value, g_destroy_func);
 	__params_it++;
-	self = g_object_newv (GEE_READ_ONLY_SET_TYPE_ITERATOR, __params_it - __params, __params);
+	self = g_object_newv (object_type, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -226,6 +238,11 @@ static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBo
 }
 
 
+static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	return gee_read_only_set_iterator_construct (GEE_READ_ONLY_SET_TYPE_ITERATOR, g_type, g_dup_func, g_destroy_func);
+}
+
+
 static void gee_read_only_set_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlySetIterator * self;
 	self = GEE_READ_ONLY_SET_ITERATOR (object);
@@ -275,15 +292,15 @@ static void gee_read_only_set_iterator_gee_iterator_interface_init (GeeIteratorI
 }
 
 
-static void gee_read_only_set_iterator_init (GeeReadOnlySetIterator * self) {
+static void gee_read_only_set_iterator_instance_init (GeeReadOnlySetIterator * self) {
 	self->priv = GEE_READ_ONLY_SET_ITERATOR_GET_PRIVATE (self);
 }
 
 
 static GType gee_read_only_set_iterator_get_type (void) {
 	static GType gee_read_only_set_iterator_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_set_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySetIterator), 0, (GInstanceInitFunc) gee_read_only_set_iterator_init };
+	if (gee_read_only_set_iterator_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySetIterator), 0, (GInstanceInitFunc) gee_read_only_set_iterator_instance_init, NULL };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_set_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_read_only_set_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlySetIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_set_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
@@ -297,7 +314,7 @@ static void gee_read_only_set_get_property (GObject * object, guint property_id,
 	self = GEE_READ_ONLY_SET (object);
 	switch (property_id) {
 		case GEE_READ_ONLY_SET_SIZE:
-		g_value_set_int (value, gee_read_only_set_real_get_size (self));
+		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -334,7 +351,7 @@ static void gee_read_only_set_class_init (GeeReadOnlySetClass * klass) {
 	g_type_class_add_private (klass, sizeof (GeeReadOnlySetPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_set_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_set_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_read_only_set_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gee_read_only_set_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -356,6 +373,7 @@ static void gee_read_only_set_gee_collection_interface_init (GeeCollectionIface
 	iface->add = gee_read_only_set_real_add;
 	iface->remove = gee_read_only_set_real_remove;
 	iface->clear = gee_read_only_set_real_clear;
+	iface->get_size = gee_read_only_set_real_get_size;
 }
 
 
@@ -364,23 +382,23 @@ static void gee_read_only_set_gee_set_interface_init (GeeSetIface * iface) {
 }
 
 
-static void gee_read_only_set_init (GeeReadOnlySet * self) {
+static void gee_read_only_set_instance_init (GeeReadOnlySet * self) {
 	self->priv = GEE_READ_ONLY_SET_GET_PRIVATE (self);
 }
 
 
-static void gee_read_only_set_dispose (GObject * obj) {
+static void gee_read_only_set_finalize (GObject* obj) {
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (obj);
 	(self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL)));
-	G_OBJECT_CLASS (gee_read_only_set_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gee_read_only_set_parent_class)->finalize (obj);
 }
 
 
 GType gee_read_only_set_get_type (void) {
 	static GType gee_read_only_set_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_set_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySet), 0, (GInstanceInitFunc) gee_read_only_set_init };
+	if (gee_read_only_set_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySet), 0, (GInstanceInitFunc) gee_read_only_set_instance_init, NULL };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_set_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_set_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_set_info = { (GInterfaceInitFunc) gee_read_only_set_gee_set_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
