@@ -32,6 +32,8 @@
 
 
 
+#define INDEX_OUT_OF_RANGE "*index >= 0 && index < self->priv->_size*"
+#define INSERT_INDEX_OUT_OF_RANGE "*index >= 0 && index <= self->priv->_size*"
 static void test_arraylist_get (void);
 static void test_arraylist_set (void);
 static void test_arraylist_insert (void);
@@ -57,8 +59,6 @@ static void _test_arraylist_iterator_gcallback (void);
 static void _main (char** args, int args_length1);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
-static const char* INDEX_OUT_OF_RANGE = "*index >= 0 && index < self->priv->_size*";
-static const char* INSERT_INDEX_OUT_OF_RANGE = "*index >= 0 && index <= self->priv->_size*";
 
 
 static void test_arraylist_get (void) {
@@ -67,12 +67,12 @@ static void test_arraylist_get (void) {
 	char* _tmp4;
 	char* _tmp5;
 	char* _tmp6;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal);
 	/* Check get for empty list*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		_tmp0 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0));
+		_tmp0 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)));
 		_tmp0 = (g_free (_tmp0), NULL);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -82,13 +82,13 @@ static void test_arraylist_get (void) {
 	/* Check get for valid index in list with one element*/
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "1");
 	_tmp1 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "1") == 0);
+	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "1") == 0);
 	_tmp1 = (g_free (_tmp1), NULL);
 	/* Check get for indexes out of range*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		char* _tmp2;
 		_tmp2 = NULL;
-		_tmp2 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1));
+		_tmp2 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)));
 		_tmp2 = (g_free (_tmp2), NULL);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -96,10 +96,10 @@ static void test_arraylist_get (void) {
 	g_test_trap_assert_failed ();
 	g_test_trap_assert_stderr (INDEX_OUT_OF_RANGE);
 	/* Check get for invalid index number*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		char* _tmp3;
 		_tmp3 = NULL;
-		_tmp3 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), -1));
+		_tmp3 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), -1)));
 		_tmp3 = (g_free (_tmp3), NULL);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -110,20 +110,20 @@ static void test_arraylist_get (void) {
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "2");
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "3");
 	_tmp4 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "1") == 0);
+	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "1") == 0);
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp5 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "2") == 0);
+	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "2") == 0);
 	_tmp5 = (g_free (_tmp5), NULL);
 	_tmp6 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "3") == 0);
+	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "3") == 0);
 	_tmp6 = (g_free (_tmp6), NULL);
 	/* Check get if list is cleared and empty again*/
 	gee_collection_clear (GEE_COLLECTION (arraylistOfString));
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		char* _tmp7;
 		_tmp7 = NULL;
-		_tmp7 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0));
+		_tmp7 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)));
 		_tmp7 = (g_free (_tmp7), NULL);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -138,10 +138,10 @@ static void test_arraylist_set (void) {
 	GeeArrayList* arraylistOfString;
 	char* _tmp0;
 	char* _tmp1;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal);
 	/* Check set when list is empty.*/
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 0);
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_set (GEE_LIST (arraylistOfString), 0, "0");
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -154,17 +154,17 @@ static void test_arraylist_set (void) {
 	/* Add item "1"*/
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 1);
 	_tmp0 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "1") == 0);
+	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "1") == 0);
 	_tmp0 = (g_free (_tmp0), NULL);
 	gee_list_set (GEE_LIST (arraylistOfString), 0, "2");
 	/* Set the item to value 2*/
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 1);
 	_tmp1 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "2") == 0);
+	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "2") == 0);
 	_tmp1 = (g_free (_tmp1), NULL);
 	/* Check set when index out of range*/
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 1);
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_set (GEE_LIST (arraylistOfString), 1, "0");
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -188,10 +188,10 @@ static void test_arraylist_insert (void) {
 	char* _tmp7;
 	char* _tmp8;
 	char* _tmp9;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal);
 	/* Check inserting in empty list
 	 Inserting at index 1*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_insert (GEE_LIST (arraylistOfString), 1, "0");
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -203,29 +203,29 @@ static void test_arraylist_insert (void) {
 	gee_list_insert (GEE_LIST (arraylistOfString), 0, "10");
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 1);
 	_tmp0 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "10") == 0);
+	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "10") == 0);
 	_tmp0 = (g_free (_tmp0), NULL);
 	/* Check insert to the beginning*/
 	gee_list_insert (GEE_LIST (arraylistOfString), 0, "5");
 	_tmp1 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "5") == 0);
+	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "5") == 0);
 	_tmp1 = (g_free (_tmp1), NULL);
 	_tmp2 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "10") == 0);
+	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "10") == 0);
 	_tmp2 = (g_free (_tmp2), NULL);
 	/* Check insert in between*/
 	gee_list_insert (GEE_LIST (arraylistOfString), 1, "7");
 	_tmp3 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "5") == 0);
+	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "5") == 0);
 	_tmp3 = (g_free (_tmp3), NULL);
 	_tmp4 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "7") == 0);
+	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "7") == 0);
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp5 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "10") == 0);
+	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "10") == 0);
 	_tmp5 = (g_free (_tmp5), NULL);
 	/* Check insert into index out of current range*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_insert (GEE_LIST (arraylistOfString), 4, "20");
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -235,19 +235,19 @@ static void test_arraylist_insert (void) {
 	/* Check insert to the end*/
 	gee_list_insert (GEE_LIST (arraylistOfString), 3, "20");
 	_tmp6 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "5") == 0);
+	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "5") == 0);
 	_tmp6 = (g_free (_tmp6), NULL);
 	_tmp7 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp7 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "7") == 0);
+	g_assert (_vala_strcmp0 ((_tmp7 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "7") == 0);
 	_tmp7 = (g_free (_tmp7), NULL);
 	_tmp8 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp8 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "10") == 0);
+	g_assert (_vala_strcmp0 ((_tmp8 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "10") == 0);
 	_tmp8 = (g_free (_tmp8), NULL);
 	_tmp9 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp9 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 3))), "20") == 0);
+	g_assert (_vala_strcmp0 ((_tmp9 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 3)))), "20") == 0);
 	_tmp9 = (g_free (_tmp9), NULL);
 	/* Check insert into invalid index*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_insert (GEE_LIST (arraylistOfString), -1, "0");
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -269,16 +269,16 @@ static void test_arraylist_remove_at (void) {
 	char* _tmp6;
 	char* _tmp7;
 	char* _tmp8;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal);
 	/* Check removing in empty list*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_remove_at (GEE_LIST (arraylistOfString), 0);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
 	}
 	g_test_trap_assert_failed ();
 	g_test_trap_assert_stderr (INDEX_OUT_OF_RANGE);
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_remove_at (GEE_LIST (arraylistOfString), 1);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -296,40 +296,40 @@ static void test_arraylist_remove_at (void) {
 	gee_list_remove_at (GEE_LIST (arraylistOfString), 0);
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 4);
 	_tmp0 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "2") == 0);
+	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "2") == 0);
 	_tmp0 = (g_free (_tmp0), NULL);
 	_tmp1 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "3") == 0);
+	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "3") == 0);
 	_tmp1 = (g_free (_tmp1), NULL);
 	_tmp2 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "4") == 0);
+	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "4") == 0);
 	_tmp2 = (g_free (_tmp2), NULL);
 	_tmp3 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 3))), "5") == 0);
+	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 3)))), "5") == 0);
 	_tmp3 = (g_free (_tmp3), NULL);
 	/* Check remove_at last*/
 	gee_list_remove_at (GEE_LIST (arraylistOfString), 3);
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 3);
 	_tmp4 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "2") == 0);
+	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "2") == 0);
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp5 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "3") == 0);
+	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "3") == 0);
 	_tmp5 = (g_free (_tmp5), NULL);
 	_tmp6 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "4") == 0);
+	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "4") == 0);
 	_tmp6 = (g_free (_tmp6), NULL);
 	/* Check remove_at in between*/
 	gee_list_remove_at (GEE_LIST (arraylistOfString), 1);
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 2);
 	_tmp7 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp7 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "2") == 0);
+	g_assert (_vala_strcmp0 ((_tmp7 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "2") == 0);
 	_tmp7 = (g_free (_tmp7), NULL);
 	_tmp8 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp8 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "4") == 0);
+	g_assert (_vala_strcmp0 ((_tmp8 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "4") == 0);
 	_tmp8 = (g_free (_tmp8), NULL);
 	/* Check remove_at when index out of range*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_remove_at (GEE_LIST (arraylistOfString), 2);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -337,7 +337,7 @@ static void test_arraylist_remove_at (void) {
 	g_test_trap_assert_failed ();
 	g_test_trap_assert_stderr (INDEX_OUT_OF_RANGE);
 	/* Check remove_at when invalid index*/
-	if (g_test_trap_fork (((guint64) 0), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
+	if (g_test_trap_fork (((guint64) (0)), G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR)) {
 		gee_list_remove_at (GEE_LIST (arraylistOfString), -1);
 		(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 		return;
@@ -356,11 +356,9 @@ static void test_arraylist_index_of (void) {
 	GObject* object2;
 	GObject* object3;
 	GObject* object4;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal);
 	/* Check empty list*/
 	g_assert (gee_list_index_of (GEE_LIST (arraylistOfString), "one") == -1);
-	/* Check invalid type*/
-	g_assert (gee_list_index_of (GEE_LIST (arraylistOfString), GINT_TO_POINTER (1)) == -1);
 	/* Check one item*/
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "one");
 	g_assert (gee_list_index_of (GEE_LIST (arraylistOfString), "one") == 0);
@@ -385,7 +383,7 @@ static void test_arraylist_index_of (void) {
 	g_assert (gee_list_index_of (GEE_LIST (arraylistOfInt), GINT_TO_POINTER (3)) == 2);
 	g_assert (gee_list_index_of (GEE_LIST (arraylistOfInt), GINT_TO_POINTER (4)) == -1);
 	/* Check list of objects*/
-	arraylistOfObjects = gee_array_list_new (G_TYPE_OBJECT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+	arraylistOfObjects = gee_array_list_new (G_TYPE_OBJECT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 	object1 = g_object_new (G_TYPE_OBJECT, NULL);
 	object2 = g_object_new (G_TYPE_OBJECT, NULL);
 	object3 = g_object_new (G_TYPE_OBJECT, NULL);
@@ -396,7 +394,6 @@ static void test_arraylist_index_of (void) {
 	g_assert (gee_list_index_of (GEE_LIST (arraylistOfObjects), object1) == 0);
 	g_assert (gee_list_index_of (GEE_LIST (arraylistOfObjects), object2) == 1);
 	g_assert (gee_list_index_of (GEE_LIST (arraylistOfObjects), object3) == 2);
-	g_assert (gee_list_index_of (GEE_LIST (arraylistOfObjects), GINT_TO_POINTER (4)) == -1);
 	(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
 	(arraylistOfInt == NULL ? NULL : (arraylistOfInt = (g_object_unref (arraylistOfInt), NULL)));
 	(arraylistOfObjects == NULL ? NULL : (arraylistOfObjects = (g_object_unref (arraylistOfObjects), NULL)));
@@ -416,7 +413,7 @@ static void test_arraylist_add (void) {
 	GeeArrayList* arrayListOfInt;
 	GeeArrayList* arrayListOfGLibObject;
 	GObject* fooObject;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal);
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "42");
 	g_assert (gee_collection_contains (GEE_COLLECTION (arraylistOfString), "42"));
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 1);
@@ -425,16 +422,16 @@ static void test_arraylist_add (void) {
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "44");
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "45");
 	_tmp0 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "42") == 0);
+	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "42") == 0);
 	_tmp0 = (g_free (_tmp0), NULL);
 	_tmp1 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "43") == 0);
+	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "43") == 0);
 	_tmp1 = (g_free (_tmp1), NULL);
 	_tmp2 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "44") == 0);
+	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "44") == 0);
 	_tmp2 = (g_free (_tmp2), NULL);
 	_tmp3 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 3))), "45") == 0);
+	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 3)))), "45") == 0);
 	_tmp3 = (g_free (_tmp3), NULL);
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 4);
 	/* check adding of ints*/
@@ -443,7 +440,7 @@ static void test_arraylist_add (void) {
 	g_assert (gee_collection_contains (GEE_COLLECTION (arrayListOfInt), GINT_TO_POINTER (42)));
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arrayListOfInt)) == 1);
 	/* check adding of objects*/
-	arrayListOfGLibObject = gee_array_list_new (G_TYPE_OBJECT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+	arrayListOfGLibObject = gee_array_list_new (G_TYPE_OBJECT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 	fooObject = g_object_new (G_TYPE_OBJECT, NULL);
 	gee_collection_add (GEE_COLLECTION (arrayListOfGLibObject), fooObject);
 	g_assert (gee_collection_contains (GEE_COLLECTION (arrayListOfGLibObject), fooObject));
@@ -457,7 +454,7 @@ static void test_arraylist_add (void) {
 
 static void test_arraylist_clear (void) {
 	GeeArrayList* arraylistOfString;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal);
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 0);
 	/* Check clear on empty list*/
 	gee_collection_clear (GEE_COLLECTION (arraylistOfString));
@@ -481,11 +478,9 @@ static void test_arraylist_clear (void) {
 static void test_arraylist_contains (void) {
 	GeeArrayList* arraylistOfString;
 	GeeArrayList* arraylistOfInt;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal);
 	/* Check on empty list*/
 	g_assert (!gee_collection_contains (GEE_COLLECTION (arraylistOfString), "1"));
-	/* Check incomaptible type*/
-	g_assert (!gee_collection_contains (GEE_COLLECTION (arraylistOfString), GINT_TO_POINTER (1)));
 	/* Check items*/
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "10");
 	g_assert (gee_collection_contains (GEE_COLLECTION (arraylistOfString), "10"));
@@ -540,11 +535,9 @@ static void test_arraylist_remove (void) {
 	char* _tmp7;
 	char* _tmp8;
 	GeeArrayList* arraylistOfInt;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal);
 	/* Check remove if list is empty*/
 	gee_collection_remove (GEE_COLLECTION (arraylistOfString), "42");
-	/* Check remove for incompatible type*/
-	gee_collection_remove (GEE_COLLECTION (arraylistOfString), GINT_TO_POINTER (10));
 	/* Add 5 same elements*/
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "42");
 	gee_collection_add (GEE_COLLECTION (arraylistOfString), "42");
@@ -572,37 +565,37 @@ static void test_arraylist_remove (void) {
 	gee_collection_remove (GEE_COLLECTION (arraylistOfString), "42");
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 4);
 	_tmp0 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "43") == 0);
+	g_assert (_vala_strcmp0 ((_tmp0 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "43") == 0);
 	_tmp0 = (g_free (_tmp0), NULL);
 	_tmp1 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "44") == 0);
+	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "44") == 0);
 	_tmp1 = (g_free (_tmp1), NULL);
 	_tmp2 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "45") == 0);
+	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "45") == 0);
 	_tmp2 = (g_free (_tmp2), NULL);
 	_tmp3 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 3))), "46") == 0);
+	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 3)))), "46") == 0);
 	_tmp3 = (g_free (_tmp3), NULL);
 	/* Check remove last*/
 	gee_collection_remove (GEE_COLLECTION (arraylistOfString), "46");
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 3);
 	_tmp4 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "43") == 0);
+	g_assert (_vala_strcmp0 ((_tmp4 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "43") == 0);
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp5 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "44") == 0);
+	g_assert (_vala_strcmp0 ((_tmp5 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "44") == 0);
 	_tmp5 = (g_free (_tmp5), NULL);
 	_tmp6 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 2))), "45") == 0);
+	g_assert (_vala_strcmp0 ((_tmp6 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 2)))), "45") == 0);
 	_tmp6 = (g_free (_tmp6), NULL);
 	/* Check remove in between*/
 	gee_collection_remove (GEE_COLLECTION (arraylistOfString), "44");
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylistOfString)) == 2);
 	_tmp7 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp7 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 0))), "43") == 0);
+	g_assert (_vala_strcmp0 ((_tmp7 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 0)))), "43") == 0);
 	_tmp7 = (g_free (_tmp7), NULL);
 	_tmp8 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp8 = ((char*) gee_list_get (GEE_LIST (arraylistOfString), 1))), "45") == 0);
+	g_assert (_vala_strcmp0 ((_tmp8 = ((char*) (gee_list_get (GEE_LIST (arraylistOfString), 1)))), "45") == 0);
 	_tmp8 = (g_free (_tmp8), NULL);
 	/* Check removing of int element*/
 	arraylistOfInt = gee_array_list_new (G_TYPE_INT, NULL, NULL, g_direct_equal);
@@ -638,7 +631,7 @@ static void test_arraylist_remove (void) {
 
 static void test_arraylist_size (void) {
 	GeeArrayList* arraylist;
-	arraylist = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal);
+	arraylist = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal);
 	/* Check empty list*/
 	g_assert (gee_collection_get_size (GEE_COLLECTION (arraylist)) == 0);
 	/* Check when one item*/
@@ -661,7 +654,7 @@ static void test_arraylist_iterator (void) {
 	char* _tmp1;
 	char* _tmp2;
 	char* _tmp3;
-	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal);
+	arraylistOfString = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal);
 	/* Check iterate empty list*/
 	iterator = gee_iterable_iterator (GEE_ITERABLE (arraylistOfString));
 	g_assert (!gee_iterator_next (iterator));
@@ -673,15 +666,15 @@ static void test_arraylist_iterator (void) {
 	iterator = (_tmp0 = gee_iterable_iterator (GEE_ITERABLE (arraylistOfString)), (iterator == NULL ? NULL : (iterator = (g_object_unref (iterator), NULL))), _tmp0);
 	g_assert (gee_iterator_next (iterator));
 	_tmp1 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) gee_iterator_get (iterator))), "42") == 0);
+	g_assert (_vala_strcmp0 ((_tmp1 = ((char*) (gee_iterator_get (iterator)))), "42") == 0);
 	_tmp1 = (g_free (_tmp1), NULL);
 	g_assert (gee_iterator_next (iterator));
 	_tmp2 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) gee_iterator_get (iterator))), "43") == 0);
+	g_assert (_vala_strcmp0 ((_tmp2 = ((char*) (gee_iterator_get (iterator)))), "43") == 0);
 	_tmp2 = (g_free (_tmp2), NULL);
 	g_assert (gee_iterator_next (iterator));
 	_tmp3 = NULL;
-	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) gee_iterator_get (iterator))), "44") == 0);
+	g_assert (_vala_strcmp0 ((_tmp3 = ((char*) (gee_iterator_get (iterator)))), "44") == 0);
 	_tmp3 = (g_free (_tmp3), NULL);
 	g_assert (!gee_iterator_next (iterator));
 	(arraylistOfString == NULL ? NULL : (arraylistOfString = (g_object_unref (arraylistOfString), NULL)));
